==> jc-1.4.0.tar.gz: java/awt/image/BufferStrategy.h <==
// public abstract class java.awt.image.BufferStrategy

// class file dependencies
// @dep_class 5615ecb69ad41bde java_awt_image_BufferStrategy
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_BufferStrategy_H_
#define _JC_java_awt_image_BufferStrategy_H_

// Forward structure declarations
struct _jc_java_awt_BufferCapabilities$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_BufferStrategy$sub_refs	_jc_java_awt_image_BufferStrategy$sub_refs;
typedef struct _jc_java_awt_image_BufferStrategy$sub_nonrefs	_jc_java_awt_image_BufferStrategy$sub_nonrefs;
typedef struct _jc_java_awt_image_BufferStrategy$refs	_jc_java_awt_image_BufferStrategy$refs;
typedef struct _jc_java_awt_image_BufferStrategy$nonrefs	_jc_java_awt_image_BufferStrategy$nonrefs;
typedef struct _jc_java_awt_image_BufferStrategy$object	_jc_java_awt_image_BufferStrategy$object;

typedef const struct _jc_java_awt_image_BufferStrategy$vmethods	_jc_java_awt_image_BufferStrategy$vmethods;
typedef const struct _jc_java_awt_image_BufferStrategy$vtable	_jc_java_awt_image_BufferStrategy$vtable;
typedef const struct _jc_java_awt_image_BufferStrategy$vtype	_jc_java_awt_image_BufferStrategy$vtype;

// Constructors
extern void _jc_java_awt_image_BufferStrategy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *);

// Virtual methods
extern jboolean _jc_java_awt_image_BufferStrategy$method$contentsLost$43f368939717a903(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *);
extern jboolean _jc_java_awt_image_BufferStrategy$method$contentsRestored$524d1efb1bd23576(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *);
extern struct _jc_java_awt_BufferCapabilities$object *_jc_java_awt_image_BufferStrategy$method$getCapabilities$bc677871f5d762f9(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *);
extern struct _jc_java_awt_Graphics$object *_jc_java_awt_image_BufferStrategy$method$getDrawGraphics$e9804cf8fbb1d8bd(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *);
extern void _jc_java_awt_image_BufferStrategy$method$show$8844e066fe447d0e(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_BufferStrategy$method_info$contentsLost$43f368939717a903;
extern _jc_method _jc_java_awt_image_BufferStrategy$method_info$contentsRestored$524d1efb1bd23576;
extern _jc_method _jc_java_awt_image_BufferStrategy$method_info$getCapabilities$bc677871f5d762f9;
extern _jc_method _jc_java_awt_image_BufferStrategy$method_info$getDrawGraphics$e9804cf8fbb1d8bd;
extern _jc_method _jc_java_awt_image_BufferStrategy$method_info$show$8844e066fe447d0e;

// Virtual methods structure
struct _jc_java_awt_image_BufferStrategy$vmethods {
	jboolean	(*contentsLost$43f368939717a903)(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *);
	jboolean	(*contentsRestored$524d1efb1bd23576)(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *);
	struct _jc_java_awt_BufferCapabilities$object	*(*getCapabilities$bc677871f5d762f9)(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *);
	struct _jc_java_awt_Graphics$object	*(*getDrawGraphics$e9804cf8fbb1d8bd)(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *);
	void	(*show$8844e066fe447d0e)(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *);
};

// Vtable
struct _jc_java_awt_image_BufferStrategy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_BufferStrategy$vmethods	java_awt_image_BufferStrategy;
};

// Vtype
struct _jc_java_awt_image_BufferStrategy$vtype {
	_jc_type			type;
	_jc_java_awt_image_BufferStrategy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_BufferStrategy$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_BufferStrategy$refs {
    _jc_java_awt_image_BufferStrategy$sub_refs	java_awt_image_BufferStrategy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_BufferStrategy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_BufferStrategy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_BufferStrategy$sub_nonrefs	java_awt_image_BufferStrategy;
};

// Object instance structure
struct _jc_java_awt_image_BufferStrategy$object {
	_jc_java_awt_image_BufferStrategy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_BufferStrategy$vtype	*vtype;
	_jc_java_awt_image_BufferStrategy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_BufferStrategy$vtype _jc_java_awt_image_BufferStrategy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_BufferStrategy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_BufferStrategy$class_object;

#endif	/* _JC_java_awt_image_BufferStrategy_H_ */

==> jc-1.4.5.tar.gz: java/awt/image/BufferStrategy.h <==
// public abstract class java.awt.image.BufferStrategy

// class file dependencies
// @dep_class 5615ecb69ad41bde java_awt_image_BufferStrategy
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_BufferStrategy_H_
#define _JC_java_awt_image_BufferStrategy_H_

// Forward structure declarations
struct _jc_java_awt_BufferCapabilities$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_BufferStrategy$sub_refs	_jc_java_awt_image_BufferStrategy$sub_refs;
typedef struct _jc_java_awt_image_BufferStrategy$sub_nonrefs	_jc_java_awt_image_BufferStrategy$sub_nonrefs;
typedef struct _jc_java_awt_image_BufferStrategy$refs	_jc_java_awt_image_BufferStrategy$refs;
typedef struct _jc_java_awt_image_BufferStrategy$nonrefs	_jc_java_awt_image_BufferStrategy$nonrefs;
typedef struct _jc_java_awt_image_BufferStrategy$object	_jc_java_awt_image_BufferStrategy$object;

typedef const struct _jc_java_awt_image_BufferStrategy$vmethods	_jc_java_awt_image_BufferStrategy$vmethods;
typedef const struct _jc_java_awt_image_BufferStrategy$vtable	_jc_java_awt_image_BufferStrategy$vtable;
typedef const struct _jc_java_awt_image_BufferStrategy$vtype	_jc_java_awt_image_BufferStrategy$vtype;

// Constructors
extern void _jc_java_awt_image_BufferStrategy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_image_BufferStrategy$method$contentsLost$43f368939717a903(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_image_BufferStrategy$method$contentsRestored$524d1efb1bd23576(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_BufferCapabilities$object *_jc_java_awt_image_BufferStrategy$method$getCapabilities$bc677871f5d762f9(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Graphics$object *_jc_java_awt_image_BufferStrategy$method$getDrawGraphics$e9804cf8fbb1d8bd(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_BufferStrategy$method$show$8844e066fe447d0e(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_BufferStrategy$method_info$contentsLost$43f368939717a903;
extern _jc_method _jc_java_awt_image_BufferStrategy$method_info$contentsRestored$524d1efb1bd23576;
extern _jc_method _jc_java_awt_image_BufferStrategy$method_info$getCapabilities$bc677871f5d762f9;
extern _jc_method _jc_java_awt_image_BufferStrategy$method_info$getDrawGraphics$e9804cf8fbb1d8bd;
extern _jc_method _jc_java_awt_image_BufferStrategy$method_info$show$8844e066fe447d0e;

// Virtual methods structure
struct _jc_java_awt_image_BufferStrategy$vmethods {
	jboolean	(*contentsLost$43f368939717a903)(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *) _JC_JCNI_ATTR;
	jboolean	(*contentsRestored$524d1efb1bd23576)(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_BufferCapabilities$object	*(*getCapabilities$bc677871f5d762f9)(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Graphics$object	*(*getDrawGraphics$e9804cf8fbb1d8bd)(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *) _JC_JCNI_ATTR;
	void	(*show$8844e066fe447d0e)(_jc_env *, struct _jc_java_awt_image_BufferStrategy$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_BufferStrategy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_BufferStrategy$vmethods	java_awt_image_BufferStrategy;
};

// Vtype
struct _jc_java_awt_image_BufferStrategy$vtype {
	_jc_type			type;
	_jc_java_awt_image_BufferStrategy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_BufferStrategy$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_BufferStrategy$refs {
    _jc_java_awt_image_BufferStrategy$sub_refs	java_awt_image_BufferStrategy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_BufferStrategy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_BufferStrategy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_BufferStrategy$sub_nonrefs	java_awt_image_BufferStrategy;
};

// Object instance structure
struct _jc_java_awt_image_BufferStrategy$object {
	_jc_java_awt_image_BufferStrategy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_BufferStrategy$vtype	*vtype;
	_jc_java_awt_image_BufferStrategy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_BufferStrategy$vtype _jc_java_awt_image_BufferStrategy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_BufferStrategy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_BufferStrategy$class_object;

#endif	/* _JC_java_awt_image_BufferStrategy_H_ */
